@@ -1,4 +1,4 @@
-/* $Id: fsusage.h,v 1.23 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: fsusage.h,v 1.24 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
 
@@ -53,7 +53,7 @@ struct _glibtop_fsusage
 	guint64 read, write;    /* Total blocks read and written */
 };
 
-#define glibtop_get_fsusage(fsusage,disk)	glibtop_get_fsusage_l(glibtop_global_server, fsusage, disk)
+void glibtop_get_fsusage(glibtop_fsusage *buf, const char *mount_dir);
 
 #define glibtop_get_fsusage_r		glibtop_get_fsusage_s
 
