@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.2 2003/10/19 16:54:39 carlos Exp $ */
+/* $Id: netload.c,v 1.5 2005/12/12 09:38:10 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <sys/socket.h>
 #include <net/if.h>
 #include <netinet/in.h>
@@ -31,7 +32,7 @@
 
 #include "utils.h"
 
-static const unsigned long _glibtop_sysdeps_netload = 
+static const unsigned long _glibtop_sysdeps_netload =
 (1 << GLIBTOP_NETLOAD_IF_FLAGS) + (1 << GLIBTOP_NETLOAD_MTU) +
 (1 << GLIBTOP_NETLOAD_SUBNET) + (1 << GLIBTOP_NETLOAD_ADDRESS) +
 (1 << GLIBTOP_NETLOAD_PACKETS_IN) + (1 << GLIBTOP_NETLOAD_PACKETS_OUT) +
@@ -119,6 +120,8 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	long mask;
 	char name[16];
 
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_UPTIME), 0);
+
 	memset (buf, 0, sizeof (glibtop_netload));
 
 	for ( offset = server->machine.ifnet_offset;
@@ -182,7 +185,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 			buf->if_flags |= (1 << GLIBTOP_IF_FLAGS_MULTICAST);
 
 		buf->mtu = ifnet.if_mtu;
-	
+
 		get_ifaddr(server, ifnet.if_addrlist, &addr, &mask);
 
 		buf->subnet = addr & mask;
