@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.19 2004/06/09 18:52:22 bdejean Exp $ */
+/* $Id: procmap.c,v 1.21 2005/12/12 09:38:13 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,12 +22,12 @@
 */
 
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procmap.h>
 
 #include <errno.h>
-#include <alloca.h>
 
 #include "safeio.h"
 
@@ -58,7 +58,7 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
    	int fd, i, nmaps, pr_err, heap;
 #if GLIBTOP_SOLARIS_RELEASE >= 560
 	prxmap_t *maps;
-	struct ps_prochandle *Pr;
+	struct ps_prochandle *Pr = NULL;
 #else
 	prmap_t *maps;
 #endif
@@ -97,7 +97,7 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 		s_close(fd);
 		return NULL;
 	}
-	maps = alloca(inode.st_size);
+	maps = g_alloca(inode.st_size);
 	nmaps = inode.st_size / sizeof(prxmap_t);
 	if(s_pread(fd, maps, inode.st_size, 0) != inode.st_size)
 	{
@@ -112,7 +112,7 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 		s_close(fd);
 		return NULL;
 	}
-	maps = alloca((nmaps + 1) * sizeof(prmap_t));
+	maps = g_alloca((nmaps + 1) * sizeof(prmap_t));
 	if(ioctl(fd, PIOCMAP, maps) < 0)
 	{
 	   	glibtop_warn_io_r(server, "ioctl(%s, PIOCMAP)", buffer);
